/*                                                                                                            
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or
 * http://eu-egee.org/license.html
 */

/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcmaps_defines.h
    \brief  Public header file with common definitions for the LCMAPS (authorization modules)
    \author Martijn Steenbakkers for the EU DataGrid.

    Here the return values for the LCMAPS plugins/modules are defined as well as the
    default locations of the LCMAPS "etc", "lib" and "modules" directories.
    \ingroup APIforLcmapsPlugins
*/

#ifndef LCMAPS_DEFINES_H
#define LCMAPS_DEFINES_H

/******************************************************************************
                             Define constants
******************************************************************************/

#define LCMAPS_MOD_SUCCESS (int)(0) /*!< Return value of LCMAPS plugin module
                                       indicating succes (authorization granted)*/
#define LCMAPS_MOD_FAIL    (int)(1) /*!< Return value of LCMAPS plugin module
                                       indicating failure (no authorization) */
#define LCMAPS_MOD_NOFILE  (int)(2) /*!< Return value of LCMAPS plugin module
                                       indicating that no file could be found */
#define LCMAPS_MOD_ENTRY   (int)(3) /*!< Return value of LCMAPS plugin module
                                       indicating that an entry was found */
#define LCMAPS_MOD_NOENTRY (int)(4) /*!< Return value of LCMAPS plugin module
                                       indicating that no entry was found */

#define LCMAPS_ETC_HOME "/opt/glite/etc/lcmaps" /*!< default directory for LCMAPS
                                               configuration data bases */
#define LCMAPS_LIB_HOME "/opt/glite/lib" /*!< default directory for the
                                               LCMAPS library */
#define LCMAPS_MOD_HOME "/opt/glite/lib/modules" /*!< default directory for
                                                       the LCMAPS plugins/modules */

#define LCMAPS_MAXPATHLEN    500 /*!< maximum path lengths of files, used in plugin
                               and database structures. \internal */
#define LCMAPS_MAXARGSTRING  2000 /*!< maximum length of the plugin argument string as
                               specified in the LCMAPS database. \internal */
#define LCMAPS_MAXARGS       51  /*!< maximum number of arguments (+1) to be passed to
                               LCMAPS authorization plugins/modules. \internal */

#endif /* LCMAPS_DEFINES_H */

/******************************************************************************
CVS Information:
    $Source: /cvs/glite/org.glite.security.lcmaps/interface/lcmaps_defines.h,v $
    $Date: 2004/10/13 16:37:57 $
    $Revision: 1.2 $
    $Author: msteenba $
******************************************************************************/
