/*                                                                                                            
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or
 * http://eu-egee.org/license.html
 */

/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcmaps_log.h
    \brief  Logging API for the LCMAPS plugins and LCMAPS itself
    \author Martijn Steenbakkers for the EU DataGrid.

    This header contains the declarations of the LCMAPS logging functions
    The LCMAPS plugins can use this API to write output to the LCMAPS logging
    devices.
    -# lcmaps_log(): Log to LCMAPS logging devices.
    -# lcmaps_log_debug(): Produce debugging output.
    \ingroup APIforLcmapsPlugins
*/

#ifndef LCMAPS_LOG_H
#define LCMAPS_LOG_H

/******************************************************************************
                             Include header files
******************************************************************************/
#include <syslog.h>

/******************************************************************************
 *                            Module definition
 *****************************************************************************/
/******************************************************************************
Function:       lcmaps_log()
Description:    Log information to file and or syslog
Parameters:
                prty:    syslog priority (if 0 don't syslog)
                fmt:     string format
Returns:        0 succes
                1 failure
******************************************************************************/
extern int lcmaps_log(
        int prty,
        char * fmt,
        ...
);

/******************************************************************************
Function:       lcmaps_log_debug()
Description:    Print debugging information
Parameters:
                debug_lvl: debugging level
                fmt:       string format
Returns:        0 succes
                1 failure
******************************************************************************/
extern int lcmaps_log_debug(
        int debug_lvl,
        char * fmt,
        ...
);

/******************************************************************************
Function:       lcmaps_log_time()
Description:    Log information to file and or syslog with a timestamp
Parameters:
                prty:    syslog priority (if 0 don't syslog)
                fmt:     string format
Returns:        0 succes
                1 failure
******************************************************************************/
extern int lcmaps_log_time(
        int prty, 
        char * fmt, 
        ...
);

/******************************************************************************
Function:       lcmaps_log_a_string()
Description:    Log a string according to the passed format to file and or syslog
Parameters:
                prty:       syslog priority (if 0 don't syslog)
                fmt:        string format
                the_string: the string
Returns:        0 succes
                1 failure
******************************************************************************/
extern int lcmaps_log_a_string(
        int prty,
        char * fmt,
        char * the_string
);

/******************************************************************************
Function:       lcmaps_log_a_string_debug()
Description:    Print debugging information
Parameters:
                debug_lvl:  debugging level
                fmt:        string format
                the_string: the string
Returns:        0 succes
                1 failure
******************************************************************************/
extern int lcmaps_log_a_string_debug(
        int debug_lvl,
        char * fmt,
        char * the_string
);
#endif /* LCMAPS_LOG_H */

/******************************************************************************
CVS Information:
    $Source: /cvs/glite/org.glite.security.lcmaps/interface/lcmaps_log.h,v $
    $Date: 2004/10/13 16:37:57 $
    $Revision: 1.3 $
    $Author: msteenba $
******************************************************************************/
