/*                                                                                                            
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://eu-egee.org/partners/ for details on the copyright holders.
 * For license conditions see the license file or
 * http://eu-egee.org/license.html
 */

/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcmaps_utils.h
    \brief  API for the utilities for the LCMAPS
    \author Martijn Steenbakkers for the EU DataGrid.

    This header contains the declarations of the LCMAPS utility functions:
    -# lcmaps_genfilename(): 
    -# lcmaps_getfexist():
    -# lcmaps_findfile():
    -# lcmaps_get_gidlist():
    \ingroup APIforLcmapsPlugins
*/

#ifndef LCMAPS_UTILS_H
#define LCMAPS_UTILS_H

/******************************************************************************
                             Include header files
******************************************************************************/
#include <grp.h>

/******************************************************************************
 *                 Module definition
 *****************************************************************************/

/*! \name FILENAME FUNCTIONS */
/*@{*/ /* Beginning of filename functions */
/******************************************************************************
Function:       lcmaps_genfilename() (copied from GLOBUS gatekeeper.c)
Description:    generate an absolute file name given a starting prefix,
                a relative or absolute path, and a suffix
                Only use prefix if path is relative.
Parameters:
Returns:        a pointer to a string which could be freeded.
******************************************************************************/
extern char * lcmaps_genfilename(
        char * prefix,
        char * path,
        char * suffix
);

/******************************************************************************
Function:       lcmaps_getfexist()
Description:    picks the first existing file in argument list
Parameters:     n   : number of paths,
                ... : list of paths
Returns:        returns filename found or NULL
******************************************************************************/
extern char * lcmaps_getfexist(
        int n,
        ...
);

/******************************************************************************
Function:       lcmaps_findfile()
Description:    Checks for file in standard directories
Parameters:     name
Returns:        returns filename found (should be freeed) or NULL
******************************************************************************/
extern char * lcmaps_findfile(
        char * name
);
/*@}*/ /* End of filename functions */

/******************************************************************************
Function:   lcmaps_get_gidlist()

Description:
    Finds the list of gids for user in the group file (/etc/group)
    Returns a list of gid_t which should be freed by calling program.

Parameters:
    username:   the name of the user
    ngroups:    ptr to int which will be filled with the number of gids.
    group_list: ptr to an array of gid_t.

Returns:
    0 on success. 
    -1 on realloc failure
    -2 on getgrent failure
    1 on failure
******************************************************************************/
extern int lcmaps_get_gidlist(
        const char * username,
        int * ngroups,
        gid_t ** group_list
);

#endif /* LCMAPS_UTILS_H */

/******************************************************************************
CVS Information:
    $Source: /cvs/glite/org.glite.security.lcmaps/interface/lcmaps_utils.h,v $
    $Date: 2004/12/02 17:32:05 $
    $Revision: 1.3 $
    $Author: msteenba $
******************************************************************************/
